# Drupal 8 Theming Guide

This theming guide is a reference of various techniques and snippets which are typically needed for front-end development scenarios on a project. Some documentation will reference high-level techniques that are inline with best practices, while others are specific code from certain tasks.  

## Sass in Drupal

* [Sass Style Organization](https://github.com/acquia-pso/cog/blob/8.x-1.x/STARTERKIT/_theming-guide/sass.md#sassorg)
* [Component Rules with Media Queries](https://github.com/acquia-pso/cog/blob/8.x-1.x/STARTERKIT/_theming-guide/sass.md#componenmqs)
* [CSS Preprocessing](https://github.com/acquia-pso/cog/blob/8.x-1.x/STARTERKIT/_theming-guide/sass.md#csspreprocess)
* [Writing Effective Style Rules](https://github.com/acquia-pso/cog/blob/8.x-1.x/STARTERKIT/_theming-guide/sass.md#effectivestyles)
* [Media Queries Coding Techniques](https://github.com/acquia-pso/cog/blob/8.x-1.x/STARTERKIT/_theming-guide/sass.md#mqtechniques)

## Using Web Fonts in Drupal

* [Adding External Web Fonts in Drupal](https://github.com/acquia-pso/cog/blob/8.x-1.x/STARTERKIT/_theming-guide/fonts.md#cdnfonts)
* [Adding Local Web Fonts in Drupal](https://github.com/acquia-pso/cog/blob/8.x-1.x/STARTERKIT/_theming-guide/fonts.md#localfonts)

## Twig for Drupal 8

* [Twig Basics](https://github.com/acquia-pso/cog/blob/8.x-1.x/STARTERKIT/_theming-guide/twig.md#twigbasics)
* [Twig Comparison and Control Operators](https://github.com/acquia-pso/cog/blob/8.x-1.x/STARTERKIT/_theming-guide/twig.md#twigcompare)
* [Twig Functions and Filters](https://github.com/acquia-pso/cog/blob/8.x-1.x/STARTERKIT/_theming-guide/twig.md#twigfunc)
* [Enable Twig Debugging](https://github.com/acquia-pso/cog/blob/8.x-1.x/STARTERKIT/_theming-guide/twig.md#twigenabledebug)
* [Debugging Options in Twig](https://github.com/acquia-pso/cog/blob/8.x-1.x/STARTERKIT/_theming-guide/twig.md#twigdebug)

## Images in Drupal

* [Create Render Array for Original Image](https://github.com/acquia-pso/cog/blob/8.x-1.x/STARTERKIT/_theming-guide/images.md#origrenderarray)
* [Create Render Array with Image Style](https://github.com/acquia-pso/cog/blob/8.x-1.x/STARTERKIT/_theming-guide/images.md#stylerenderarray)
* [Create Image Object from URI](https://github.com/acquia-pso/cog/blob/8.x-1.x/STARTERKIT/_theming-guide/images.md#imguri)
* [Return Image Information from File ID](https://github.com/acquia-pso/cog/blob/8.x-1.x/STARTERKIT/_theming-guide/images.md#imgfiduri)
* [Compressing Images with Gulp](https://github.com/acquia-pso/cog/blob/8.x-1.x/STARTERKIT/_theming-guide/images.md#gulpcompr)

## Drupal 8 Libraries

* [Defining Local Libraries in Drupal 8](https://github.com/acquia-pso/cog/blob/8.x-1.x/STARTERKIT/_theming-guide/libraries.md#locallibs)
* [Defining External Libraries in Drupal 8](https://github.com/acquia-pso/cog/blob/8.x-1.x/STARTERKIT/_theming-guide/libraries.md#remotelibs)
* [Adding Library Dependencies](https://github.com/acquia-pso/cog/blob/8.x-1.x/STARTERKIT/_theming-guide/libraries.md#dependencylibs)
* [Attaching Libraries within Twig files](https://github.com/acquia-pso/cog/blob/8.x-1.x/STARTERKIT/_theming-guide/libraries.md#attachtwig)
* [Attaching Libraries within Preprocess Functions](https://github.com/acquia-pso/cog/blob/8.x-1.x/STARTERKIT/_theming-guide/libraries.md#preprocesslibraries)
* [Replacing or Removing Libraries](https://github.com/acquia-pso/cog/blob/8.x-1.x/STARTERKIT/_theming-guide/libraries.md#replaceremovelibs)

## Preprocessing in Drupal

* [Creating and Passing Custom Variables to Twig](https://github.com/acquia-pso/cog/blob/8.x-1.x/STARTERKIT/_theming-guide/preprocessing.md#customvars)
* [Creating Body Classes based on User Role](https://github.com/acquia-pso/cog/blob/8.x-1.x/STARTERKIT/_theming-guide/preprocessing.md#userrole)
* [Counting and Creating Classes per Region](https://github.com/acquia-pso/cog/blob/8.x-1.x/STARTERKIT/_theming-guide/preprocessing.md#regionvar)
* [Creating a Body Class for the Homepage](https://github.com/acquia-pso/cog/blob/8.x-1.x/STARTERKIT/_theming-guide/preprocessing.md#homepage)
* [Creating a Theme-Specific Variable for Twig](https://github.com/acquia-pso/cog/blob/8.x-1.x/STARTERKIT/_theming-guide/preprocessing.md#themespec)
* [Creating Body Classes based on Path Alias](https://github.com/acquia-pso/cog/blob/8.x-1.x/STARTERKIT/_theming-guide/preprocessing.md#pathalias)
* [Creating Body Classes based on Node Type](https://github.com/acquia-pso/cog/blob/8.x-1.x/STARTERKIT/_theming-guide/preprocessing.md#nodetype)
* [Common Variables in Twig files](https://github.com/acquia-pso/cog/blob/8.x-1.x/STARTERKIT/_theming-guide/preprocessing.md#commonvars)

## JavaScript in Drupal 

* [Adding a Javascript file in Drupal](https://github.com/acquia-pso/cog/blob/8.x-1.x/STARTERKIT/_theming-guide/javascript.md#jsfile)
* [Wrapping your JavaScript code in closure](https://github.com/acquia-pso/cog/blob/8.x-1.x/STARTERKIT/_theming-guide/javascript.md#wrappingfile)
* [Adding JS code within Drupal.behaviors](https://github.com/acquia-pso/cog/blob/8.x-1.x/STARTERKIT/_theming-guide/javascript.md#behaviors)
